pecos.qeclib.qubit.tq\_cliffords
================================

.. automodule:: pecos.qeclib.qubit.tq_cliffords











   .. rubric:: Classes

   .. autosummary::

      CX
      CY
      CZ
      SXX
      SXXdg
      SYY
      SYYdg
      SZZ
      SZZdg
